@@ -57,7 +57,7 @@ EXECUTE {
   if (opt.size()) axis = opt[0][0].get_int();
 
   int num_images = argument.size()-1;
-  RefPtr<Image::Object> in[num_images];
+  std::vector< RefPtr<Image::Object> > in (num_images);
   in[0] = argument[0].get_image();
   Image::Header header (in[0]->header());
 
