@@ -259,7 +259,7 @@ class Threader {
         max_num_attempts = to<guint> (properties["max_num_attempts"]);
 
       unidirectional = to<int> (properties["unidirectional"]);
-      min_size = round (to<float> (properties["min_dist"]) / to<float> (properties["step_size"]));
+      min_size = MR::round (to<float> (properties["min_dist"]) / to<float> (properties["step_size"]));
 
       writer.create (output_file, properties);
     }
@@ -271,7 +271,7 @@ class Threader {
       currently_running = num_threads;
       guint rng_seed = time (NULL);
 
-      Glib::Thread* threads[num_threads];
+      std::vector<Glib::Thread*> threads (num_threads);
       for (int n = 0; n < num_threads; n++) {
         trackers[n]->set_rng_seed (rng_seed + n);
         threads[n] = Glib::Thread::create (sigc::bind<Tracker::Base*> (sigc::mem_fun (*this, &Threader::execute), trackers[n]), true);
@@ -329,14 +329,16 @@ class Threader {
           if (writer.count < max_num_tracks) {
             writer.append (*tck);
             writer.total_count++;
-            fprintf (stderr, "\r%8u generated, %8u selected    [%3d%%]", 
-                writer.total_count, writer.count, (int) ((100.0*writer.count)/(float) max_num_tracks));
+            if (App::log_level) 
+              fprintf (stderr, "\r%8u generated, %8u selected    [%3d%%]", 
+                  writer.total_count, writer.count, (int) ((100.0*writer.count)/(float) max_num_tracks));
           }
           delete tck;
         }
       } while (currently_running > 0);
 
-      fprintf (stderr, "\r%8u generated, %8u selected    [100%%]\n", writer.total_count, writer.count);
+      if (App::log_level) 
+        fprintf (stderr, "\r%8u generated, %8u selected    [100%%]\n", writer.total_count, writer.count);
       writer.close ();
     }
 
