@@ -23,6 +23,7 @@
 #ifndef __mrview_sidebar_roi_analysis_h__
 #define __mrview_sidebar_roi_analysis_h__
 
+#include <gtkmm/button.h>
 #include <gtkmm/checkbutton.h>
 #include <gtkmm/scrolledwindow.h>
 #include <gtkmm/frame.h>
@@ -45,15 +46,23 @@ namespace MR {
           bool on_button_press (GdkEventButton* event);
           bool on_motion (GdkEventMotion* event);
           bool on_button_release (GdkEventButton* event);
-
+ 	  bool on_key_press (GdkEventKey* event);
         protected:
-          Gtk::CheckButton     show_ROIs;
+	  Gtk::CheckButton     show_ROIs;
           Gtk::Frame           roi_frame, transparency_frame, brush_size_frame;
           Gtk::HScale          transparency, brush_size;
+	  Gtk::CheckButton     brush3d;
+  	  Gtk::CheckButton     isobrush;
+          Gtk::Button          fill_button, undo_button, redo_button, duplicate_from_previous_button, duplicate_from_next_button;
           Gtk::ScrolledWindow  roi_scrolled_window;
           DP_ROIList           roi_list;
 
           void  on_change ();
+          void  on_undo ();
+          void  on_redo ();
+          void  on_fill ();
+          void  on_copy_previous ();
+          void  on_copy_next ();
       };
 
     }
