@@ -1,4 +1,5 @@
 from sysconf.common import *
+import shlex
 
 obj_suffix = '.o'
 exe_suffix = ''
@@ -6,7 +7,17 @@ lib_prefix = 'lib'
 lib_suffix = '.so'
 
 cpp = [ 'g++', '-c', '$flags$', '$gtk$', '$path$', '$src$', '-o', '$obj$' ]
-cpp_flags = [ '-Wall', '-pedantic', '-march=native', '-fPIC', '-fno-strict-aliasing', '-DGL_GLEXT_PROTOTYPES', '-DUSE_TR1' ]
+cpp_flags = [ '-Wall', '-pedantic', '-fPIC', '-fno-strict-aliasing', '-DGL_GLEXT_PROTOTYPES', '-DUSE_TR1' ]
+# set CPP_MARCH environment variable to override -march=native option
+# set to empty string to remove option altogether
+if 'CPP_MARCH' in os.environ.keys():
+  march=os.environ['CPP_MARCH']
+  if len(march):
+    cpp_flags += [ '-march='+march ]
+else:
+  cpp_flags += [ '-march=native' ]
+
+
 
 ld = [ 'g++', '$flags$', '$path$', '$obj$', '$mrtrix$', '$gsl$', '$gtk$', '$lz$', '-o', '$bin$' ]
 ld_flags = [ '-Wl,-rpath,$ORIGIN/../lib' ]
@@ -15,6 +26,11 @@ ld_flags_lib_prefix = '-l'
 ld_lib = [ 'g++', '-shared', '$flags$', '$obj$', '-o', '$lib$' ]
 ld_lib_flags = []
 
+if 'LDFLAGS' in os.environ.keys(): 
+  env_flags = shlex.split (os.environ['LDFLAGS'])
+  ld_flags += env_flags
+  ld_lib_flags += env_flags
+
 cpp_flags_debug = cpp_flags + [ '-g' ]
 ld_flags_debug = ld_flags + [ '-g' ]
 ld_lib_flags_debug = ld_lib_flags + [ '-g' ]
